@@ -51,6 +51,8 @@ class Stack(object):
         self.shared_namespaces = {}
 
         self.groups_and_vars = SharedMap(self.manager)
+        self.lb_sec_groups = SharedMap(self.manager)
+
         """
         Deployers stash inventory data for any newly-created servers in this
         mapping object.  Note: uses SharedMap because this must be
@@ -120,6 +122,22 @@ class Stack(object):
             if attr.startswith(prefix):
                 return res
 
+    def add_lb_secgroup(self, lb_name, hosts, port):
+        """
+        Used by the load balancer deployer to register a hostname
+        for a load balancer, in order that security group rules can be
+        applied later. This is multiprocess-safe, but since keys are
+        accessed only be a single load balancer deployer there should be
+        no conflicts.
+
+        :param str lb_name: The load balancer name (as per the config file)
+
+        :param :class:`list` hosts:  The load balancer host[s], once known
+
+        :param port:  The backend port that the LB will connect on
+        """
+        self.lb_sec_groups.merge(lb_name, {'hosts': hosts, 'port': port})
+
     def add_host(self, host, group_names=None, host_vars=None):
         """
         Used by deployers to add hosts to the inventory.
@@ -219,12 +237,27 @@ class Stack(object):
             $HOME/bang-stacks/common_modules/
 
         """
+        cfg = self.config
         bang_config_dir = os.path.abspath(
-                os.path.dirname(self.config.filepath)
+                os.path.dirname(cfg.filepath)
                 )
-        ansible_module_dir = os.path.join(bang_config_dir, 'common_modules')
         playbook_dir = os.path.join(bang_config_dir, 'playbooks')
-        for playbook in self.config.get(A.PLAYBOOKS, []):
+        creds = cfg.get(A.DEPLOYER_CREDS, {})
+        pb_kwargs = {
+                # this allows connection reuse using "ControlPersist":
+                'transport': 'ssh',
+                'module_path': os.path.join(bang_config_dir, 'common_modules'),
+                'remote_pass': creds.get(A.creds.SSH_PASS),
+                # TODO: determine forks
+                # 'forks': options.forks,
+                }
+        # only add the 'remote_user' kwarg if it's in the config, otherwise use
+        # ansible's default behaviour.
+        ssh_user = creds.get(A.creds.SSH_USER)
+        if ssh_user:
+            pb_kwargs['remote_user'] = ssh_user
+
+        for playbook in cfg.get(A.PLAYBOOKS, []):
             playbook_path = os.path.join(playbook_dir, playbook)
 
             # gratuitously stolen from main() in ``ansible-playbook``
@@ -232,21 +265,21 @@ class Stack(object):
             playbook_cb = PlaybookCallbacks(verbose=1)
             runner_cb = PlaybookRunnerCallbacks(stats, verbose=1)
 
-            pb = PlayBook(
-                playbook=playbook_path,
-                module_path=ansible_module_dir,
+            extra_kwargs = {
+                    'playbook': playbook_path,
 
-                # ``host_list`` is used to generate the inventory, but don't
-                # worry, we override the inventory later
-                host_list=[],
+                    # TODO: do we really need new instances of the following
+                    # for each playbook?
+                    'callbacks': playbook_cb,
+                    'runner_callbacks': runner_cb,
+                    'stats': stats,
 
-                # TODO: determine forks
-                # forks=options.forks,
-
-                callbacks=playbook_cb,
-                runner_callbacks=runner_cb,
-                stats=stats,
-            )
+                    # ``host_list`` is used to generate the inventory, but
+                    # don't worry, we override the inventory later
+                    'host_list': [],
+                    }
+            pb_kwargs.update(extra_kwargs)
+            pb = PlayBook(**pb_kwargs)
             pb.inventory = BangsibleInventory(
                     copy.deepcopy(self.groups_and_vars.lists),
                     copy.deepcopy(self.groups_and_vars.dicts),
